@@ -43,8 +43,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2/coverage.info',
- 'COVERAGE_REPORT': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2/lcov-report',
+ 'COVERAGE_INFO': '/input/python-3.10.10-0/Python-3.10.10/coverage.info',
+ 'COVERAGE_REPORT': '/input/python-3.10.10-0/Python-3.10.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -100,7 +100,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -276,6 +276,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_J1939_H': 1,
@@ -438,6 +439,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -682,7 +684,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.2-0/Python-3.10.2',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/input/python-3.10.10-0/Python-3.10.10',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -721,13 +723,13 @@ build_time_vars = {'ABIFLAGS': '',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.2-0/Python-3.10.2 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/input/python-3.10.10-0/Python-3.10.10 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.2-0/Python-3.10.2 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/input/python-3.10.10-0/Python-3.10.10 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -755,8 +757,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2',
- 'abs_srcdir': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2',
+ 'abs_builddir': '/input/python-3.10.10-0/Python-3.10.10',
+ 'abs_srcdir': '/input/python-3.10.10-0/Python-3.10.10',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
